@@ -7,6 +7,7 @@ use ed25519_dalek as ed;
 
 use std::fmt;
 use std::convert::{TryFrom, TryInto};
+use std::hash::{Hash, Hasher};
 
 #[derive(Clone, PartialEq, Eq)]
 pub struct PublicKey {
@@ -67,6 +68,12 @@ impl fmt::Display for PublicKey {
 	}
 }
 
+impl Hash for PublicKey {
+	fn hash<H: Hasher>(&self, state: &mut H) {
+		self.as_ref().hash(state)
+	}
+}
+
 impl TryFrom<&[u8]> for PublicKey {
 	type Error = TryFromError;
 
